﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class scr_draw_sine_copy : MonoBehaviour
{

    public Vector3 origin;
    public int meshSize = 500;
    public float lineWidth = 0.2f;
    public List<string> types;
    public List<float> periods;
    public List<float> amps;

    private LineRenderer lr;
    private Transform trans;
    private float waveWidth = 3;

    // Use this for initialization
    void Start()
    {
        lr = GetComponent<LineRenderer>();
        lr.SetWidth(lineWidth, lineWidth);
        trans = GetComponent<Transform>();
    }

    // Update is called once per frame
    void Update()
    {
        Vector3[] corners = new Vector3[meshSize];

        for (int i = 0; i < meshSize; i++) {
            float t = i * waveWidth / meshSize - waveWidth / 2.0f;
            corners[i] = new Vector3(origin.x + t, origin.y + compositeWave(t, types, periods, amps), 0);
        }
        lr.SetVertexCount(meshSize);
        lr.SetPositions(corners);
        trans.position = corners[corners.Length - 1];
    }

    public float compositeWave(float t, List<string> types, List<float> periods, List<float> amps)
    {
        float value = 0;

        for (int i = 0; i < types.Count; i++) {
            if (types[i] == "sine") {
                value += sinWave(t, periods[i], amps[i]);
            }
            else if (types[i] == "square") {
                value += squareWave(t, periods[i], amps[i]);
            }
        }

        return value; //0 if no types match
    }

    float sinWave(float t, float period, float amp)
    {
        float shift = Time.time;

        return amp*Mathf.Sin((t + shift) * period * Mathf.PI);
    }

    float squareWave(float t, float period, float amp)
    {
        float shift = Time.time;

        return amp * (2 * Mathf.Ceil(0.9999f * Mathf.Sin((t + shift) * period * Mathf.PI)) - 1); //0.9999f is dampening factor to avoid going to -1
    }
}